TextRenderer class

Used to conver the tree of NodeV2 nodes into a list of RichText which resemble the paragraphs of the text

Constructors

TextRenderer(String rawHtml, RendererStyle rendererDecoration, int? maxLength, int? maxLines, List<RichTextPlaceholder> placeholders, String placeholderMarker, bool ignoreLinebreaks)
recursively parses the richtext-tree

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreLinebreaks → bool
should linebreaks like in the
final
maxLength → int?
optional maxLength used to cut off the text after a certain number of characters (tags excluded)
final
maxLines → int?
optional maximum number of lines to be displayed
final
paragraphs → RichText
displayable widgets
no setter
placeholderMarker → String
trialing and leading string to identify variables in the text
final
placeholders → List<RichTextPlaceholder>
variables used in the text
final
rawHtml → String
root of the tree to be converted
final
rendererDecoration → RendererStyle
renderer settings to be applied
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited