FlatNodeV3 class

Constructors

FlatNodeV3(String text, TextStyle style, [String? linkTarget, bool invokesNewLineBefore = false, bool invokesNewLineAfter = false])

Properties

hashCode → int
The hash code for this object.
no setterinherited
invokesNewLineAfter → bool
final
invokesNewLineBefore → bool
final
linkTarget → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited