NodeV3 class

Constructors

NodeV3(int start, int end, {Tag? tag, String? content, NodeV3? parent})
NodeV3.root()
used to group possible multiple tags on the root level under one node
factory

Properties

children → List<NodeV3>
Children nodes.
final
content → String?
final
end ↔ int
start index (inclusive), end index (exclusive)
getter/setter pair
endHtmlTag → String
creates a valid end-tag representation for this node (HTML)
no setter
face → String
no setter
hasChildren → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
innerScopeEnd → int
no setter
innerScopeStart → int
no setter
isFirstChild → bool
no setter
isLastChild → bool
no setter
isPlaintext → bool
no setter
isRoot → bool
no setter
isTag → bool
no setter
parent ↔ NodeV3?
getter/setter pair
parentIndex → int
no setter
pathToRoot → List<NodeV3>
no setter
root → NodeV3
path from this to root
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeEnd → int
no setter
scopeStart → int
no setter
start ↔ int
start index (inclusive), end index (exclusive)
getter/setter pair
startHtmlTag → String
creates a valid start-tag representation for this node (HTML)
no setter
tag → Tag?
final

Methods

addChild(NodeV3 child, [int? position]) → void
addChildren(List<NodeV3> elements, [int? position]) → void
deleteFromTree() → NodeV3
findFirstTag(List<String> tagList) → Tag?
hasPlaintextSelectionMatch(int selectionStart, int selectionEnd) → bool
insertTagNodeAbove(Tag tag) → NodeV3
isFullySelected(int selectionStart, int selectionEnd) → bool
isSelected(int selectionStart, int selectionEnd) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset({int startOffset = 0, int endOffset = 0}) → void
printTree({int spaceOffset = 0}) → void
putStyleProperty(String stylePropertyKey, String value) → void
query(NodeQuery query, {int? maxDepth}) → dynamic
select(int selectionStart, int selectionEnd) → List<NodeV3>
splitForSelection(int selectionStart, int selectionEnd) → void
toHtml() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited