LightHtmlRichTextEditor class

Lightweight HTML editor with optional preview function. Uses all width available and the minimal height. Needs bounded width.

Inheritance

Constructors

LightHtmlRichTextEditor({Key? key, TextStyle? labelTextStyle, bool showPreview = true, String? initialValue, int? maxLength, String placeholderMarker = "\\\$", List<RichTextPlaceholder> placeholders = const [], void onChanged(String valueNew) = LightHtmlRichTextEditor._doNothingWithResult, EditorDecoration editorDecoration = const EditorDecoration(), List<String> availableColors = TextConstants.defaultColors, bool alwaysShowButtons = false, LightHtmlEditorController? controller, List<Widget>? additionalActionButtons, bool animatePreviewToEditorPosition = true, bool autofocus = false, RendererStyle previewDecoration = const RendererStyle(), List<ButtonRowType> availableButtons = ButtonRowType.values})
Creates a new instance of a HTML text editor. editorLabel is displayed at the text input, styled by labelStyle when not focused, styled by focusedLabelStyle else
const

Properties

additionalActionButtons → List<Widget>?
final
alwaysShowButtons → bool
final
animatePreviewToEditorPosition → bool
final
autofocus → bool
final
availableButtons → List<ButtonRowType>
final
availableColors → List<String>
final
controller → LightHtmlEditorController?
final
editorDecoration → EditorDecoration
final
hashCode → int
The hash code for this object.
no setterinherited
initialValue → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelTextStyle → TextStyle?
final
maxLength → int?
final
onChanged → void Function(String valueNew)
final
placeholderMarker → String
final
placeholders → List<RichTextPlaceholder>
final
previewDecoration → RendererStyle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPreview → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _LightHtmlRichTextEditorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited